from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.contrib.auth.models import User

from .models import UserProfile

class UserProfileInline(admin.StackedInline):
	model = UserProfile
	can_delete = False

class UserAdmin(UserAdmin):

	list_display = UserAdmin.list_display + ('avatar_admin',)
	inlines = (UserProfileInline,)

	def avatar_admin(self, obj):
		if obj.userprofile.avatar:
			html = '<figure><img width="60px" height="60px" src="%s"></figure>' % (obj.userprofile.avatar.url)
		else:	
			html = '<figure><img width="60px" height="60px" src="%s"></figure>' % ('/static/img/default.png')
		return html

	avatar_admin.allow_tags = True
	avatar_admin.short_description = 'Avatar'

admin.site.unregister(User)
admin.site.register(User, UserAdmin)


from django.core.files.storage import FileSystemStorage
from django.conf import settings
import os

class OverwriteStorage(FileSystemStorage):

	def get_available_name(self, name):

		if self.exists(name):
			os.remove(os.path.join(settings.MEDIA_ROOT, name))
		return name


#encoding:utf-8
#from .models import UserProfile
from django.contrib.auth.models import User
from django import forms
from django.conf import settings
from django.contrib.auth.forms import UserCreationForm
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth import authenticate

class EmailUserCreationForm(UserCreationForm):

	username = forms.CharField(widget=forms.TextInput(attrs={'class': 'input', 'placeholder':_('Username')}))
	email = forms.EmailField(widget=forms.EmailInput(attrs={'class': 'input', 'placeholder':_('Email')}))
	password1 = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'input', 'placeholder':_('Password')}))
	password2 = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'input', 'placeholder':_('Repeat password')}))

	class Meta:
		model = User
		fields = ('username', 'email')


class UserLoginForm(forms.Form):

	username = forms.CharField(widget=forms.TextInput(attrs={'class': 'input', 'placeholder':_('Username')}))
	password = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'input', 'placeholder':_('Password')}))

	def __init__(self, *args, **kwargs):
		self.user_cache = None
		super(UserLoginForm, self).__init__(*args, **kwargs)

	def clean(self):
		username = self.cleaned_data.get('username')
		password = self.cleaned_data.get('password')
		self.user_cache = authenticate(username=username, password=password)

		if self.user_cache is None:
			raise forms.ValidationError(_('Incorrect user'))
		elif not self.user_cache.is_active:
			raise forms.ValidationError(_('Inactive user'))

		return self.cleaned_data

	def get_user(self):
		return self.user_cache


from .storage import OverwriteStorage
from cStringIO import StringIO 
from django.conf import settings
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from django.core.files.uploadedfile import SimpleUploadedFile
from django.db import models
from PIL import Image
from django.db.models.signals import post_save, pre_save
import os


class UserProfile(models.Model):

	user = models.OneToOneField(User)

	def save_avatar(self, filename):

		extension = filename[filename.rfind('.'):]
		new_path = 'user_profile/%s-avatar%s' %(self.user.username, extension)
		return new_path

	avatar = models.ImageField(storage=OverwriteStorage(), upload_to=save_avatar, blank=True)

	def __unicode__(self):
		return self.user.username

	def resize_avatar(self):
		# code from with some changes : http://www.yilmazhuseyin.com/blog/dev/create-thumbnails-imagefield-django/
		if not self.avatar:
			return

		try:
			AVATAR_SIZE = settings.AVATAR_SIZE
		except:
			AVATAR_SIZE = (200,200)

		DJANGO_TYPE = self.avatar.file.content_type 

		image = Image.open(StringIO(self.avatar.read()))
		image = image.resize(AVATAR_SIZE, Image.ANTIALIAS)

		temp_handle = StringIO()
		image.save(temp_handle, 'jpeg')
		temp_handle.seek(0)

		suf = SimpleUploadedFile(os.path.split(self.avatar.name)[-1],temp_handle.read(), content_type='image/jpeg')
		self.avatar.save('%s.%s' %(os.path.splitext(suf.name)[0], 'jpg'),suf, save=False)

	def save(self, *args, **kwargs):
		self.resize_avatar()
		super(UserProfile, self).save()

	def get_avatar(self):
		if self.avatar:
			avatar_url = self.avatar.url
		else:	
			avatar_url = '/static/img/default.png'
		return avatar_url

def create_user_profile(sender, instance, **kwargs):
	p = UserProfile.objects.get_or_create(user=instance)

post_save.connect(create_user_profile, sender=User,dispatch_uid="Userprofile created")
